#' ---
#' author: "Pablo Diego-Rosell, PhD"
#' email: "pablo_diego_rosell@yahoo.com"
#' output:
#'    html_document:
#'      toc: true
#' theme: united
#' ---

rm(list=ls(all=t))

#' #Setup filenames, data, functions and create dictionary for dataset review

filename <- "Malawi_Child_Public Use" # !!!Update filename
functions_vers <-  "functions_1.7.R" # !!!Update helper functions file
source (functions_vers)

#'
#' Visually inspect variables in "dictionary.csv" and flag for risk, using the following flags: 
# Direct PII: Respondent Names, Addresses, Identification Numbers, Phone Numbers
# Direct PII-team: Interviewer Names, other field team names 
# Indirect PII-ordinal: Date of birth, Age, income, education, household composition. 
# Indirect PII-categorical: Gender, education, ethnicity, nationality,
# occupation, employer, head of household, marital status
# GPS: Longitude, Latitude
# Small Location: Location (<100,000) 
# Large Location (>100,000)
# Weight: weightVar
# Household ID:  hhId, 
# Open-ends: Review responses for any sensitive information, redact as necessary 

#' #Direct PII: variables to be removed
# !!!No Direct PII

#' #Direct PII-team: Encode field team names
# !!!No Direct PII-team

#' #Small locations: Encode locations  with pop <100,000 using random large numbers
#  !!!Include relevant variables, but check their population size first to confirm they are <100,000

locvars <- c("community",
             "b_community",
             "e_community",
             "b_ta",
             "b_comm") 
mydata <- encode_location (variables= locvars, missing=999999)

#' #Indirect PII - Ordinal: Global recode or Top/bottom coding for extreme values

# Top code household composition variables with large and unusual numbers 

mydata <- top_recode ("num_people", break_point=10, missing=c(888, 999999)) # Topcode cases with 10 or more household members. 
mydata <- top_recode ("b_num_people", break_point=10, missing=c(888, 999999)) # Topcode cases with 10 or more household members. 
mydata <- top_recode("b_child_number",  break_point=6, missing=c(888, 999999)) # Topcode cases with 7 or more child household members.
mydata <- top_recode ("e_num_people", break_point=10, missing=c(888, 999999)) # Topcode cases with 10 or more household members.


#' #Indirect PII - Categrical: Recode, encode, or Top/bottom coding for extreme values
# !!!Include relevant variables in list below (Indirect PII - Categorical, and Ordinal if not processed yet)

indirect_PII <- c("yardwork",
                  "bird",
                  "firewood",
                  "hrsweek",
                  "b_yardwork",
                  "b_bird",
                  "b_firewood",
                  "b_bar",
                  "e_num_people",
                  "e_yardwork",
                  "e_bird",
                  "e_firewood",
                  "b_youngchild_a",
                  "b_youngchild_b",
                  "b_youngchild_c",
                  "b_youngchild_d",
                  "b_youngchild_e",
                  "b_youngchild_f",
                  "b_youngchild_g",
                  "b_youngchild_h",
                  "b_youngchild_i",
                  "b_youngchild_j",
                  "b_d2_a",
                  "b_d2_b",
                  "b_d2_c",
                  "b_d2_d",
                  "b_d3c",
                  "b_w2a",
                  "b_kidelse_a",
                  "b_w3c_a",
                  "b_w2b",
                  "b_kidelse_b",
                  "b_w3c_b",
                  "b_w2c",
                  "b_kidelse_c",
                  "b_w3c_c",
                  "b_w2d",
                  "b_kidelse_d",
                  "b_w3c_d",
                  "b_w2e",
                  "b_kidelse_e",
                  "b_w3c_e",
                  "b_w2f",
                  "b_kidelse_f",
                  "b_w3c_f",
                  "b_w2g",
                  "b_kidelse_g",
                  "b_w3c_g",
                  "b_w2h",
                  "b_kidelse_h",
                  "b_w3c_h",
                  "b_w2i",
                  "b_kidelse_i",
                  "b_w3c_i",
                  "b_w2j",
                  "b_kidelse_j",
                  "b_w3c_j",
                  "b_w2k",
                  "b_w2l",
                  "b_w3c_l",
                  "b_w2m",
                  "b_kidelse_m",
                  "b_w3c_m",
                  "b_w2o",
                  "b_kidelse_o",
                  "b_w3c_o",
                  "b_w2p",
                  "b_kidelse_p",
                  "b_w3c_p",
                  "b_w2q",
                  "b_kidelse_q",
                  "b_w3c_q",
                  "b_w2r",
                  "b_kidelse_r",
                  "b_w3c_r",
                  "b_kidtobseas",
                  "b_w4a",
                  "b_w4b",
                  "b_w5",
                  "b_hw1a",
                  "b_hw1b",
                  "b_hw1c",
                  "b_hw1d",
                  "b_hw1e",
                  "b_hw1f",
                  "b_hw1g",
                  "b_hw1i",
                  "b_hw1k",
                  "b_hw1m",
                  "b_hw1n",
                  "b_hw1o",
                  "b_hw2",
                  "b_hw3",
                  "b_hw4a",
                  "b_hw4b",
                  "b_hw4c",
                  "b_hw4d",
                  "b_hw4e",
                  "b_hw4f",
                  "b_hw4g",
                  "b_hw4h",
                  "b_hw4i",
                  "b_hw4j",
                  "b_hw4k",
                  "b_hw4l",
                  "b_hw4m",
                  "b_hw4n",
                  "b_hw5a",
                  "b_hw5b",
                  "b_hw5c",
                  "b_hw5d",
                  "e_youndchild_a",
                  "e_youndchild_b",
                  "e_youndchild_c",
                  "e_youndchild_d",
                  "e_youndchild_e",
                  "e_youndchild_f",
                  "e_youndchild_g",
                  "e_youndchild_h",
                  "e_youndchild_i",
                  "e_youndchild_j",
                  "e_d3c",
                  "e_kidemp_a",
                  "e_kidemp_b",
                  "e_kidemp_c",
                  "e_kidemp_d",
                  "e_kidemp_e",
                  "e_kidemp_f",
                  "e_kidemp_g",
                  "e_kidemp_h",
                  "e_kidemp_i",
                  "e_kidemp_j",
                  "e_kidemp_k",
                  "e_kidemp_l",
                  "e_kidemp_m",
                  "e_kidemp_n",
                  "e_kidemp_o",
                  "e_kidemp_p",
                  "e_kidemp_q",
                  "e_kidemp_r",
                  "e_kidelse_b",
                  "e_kidelse_c",
                  "e_kidelse_d",
                  "e_kidelse_e",
                  "e_kidelse_f",
                  "e_kidelse_g",
                  "e_kidelse_h",
                  "e_kidelse_i",
                  "e_kidelse_j",
                  "e_kidelse_k",
                  "e_kidelse_l",
                  "e_kidelse_m",
                  "e_kidelse_n",
                  "e_kidelse_o",
                  "e_kidelse_p",
                  "e_kidelse_q",
                  "e_kidelse_r",
                  "e_w3_4a",
                  "e_w3_4b",
                  "e_w3_4c",
                  "e_w3_4d",
                  "e_w3_4e",
                  "e_w3_4h",
                  "e_w3_4i",
                  "e_w3_4j",
                  "e_w3_4l",
                  "e_w3_4n",
                  "e_w3_4o",
                  "e_w3_4p",
                  "e_w3_4q",
                  "e_w3_4r",
                  "e_tobseas",
                  "e_w4a",
                  "e_w4b",
                  "e_w5",
                  "e_hw1_f",
                  "e_hw1_g",
                  "e_hw1_l",
                  "e_hw1_m",
                  "e_hw1_n",
                  "e_hw1_o",
                  "e_hw2",
                  "e_hw3",
                  "e_hw3_e",
                  "e_hw4_a",
                  "e_hw4_b",
                  "e_hw4_c",
                  "e_hw4_d",
                  "e_hw4_e",
                  "e_hw4_h",
                  "e_hw4_i",
                  "e_hw4_j",
                  "e_hw4_k",
                  "e_hw4_l",
                  "e_hw4_m",
                  "e_hw4_n",
                  "e_hw5_a",
                  "e_hw5_b",
                  "e_hw5_c")

capture_tables (indirect_PII)

# Recode those with very specific values.

#' #Matching and crosstabulations: Run automated PII check 

# Based on dictionary inspection, select variables for creating sdcMicro object
# See: https://sdcpractice.readthedocs.io/en/latest/anon_methods.html
# All variable names should correspond to the names in the data file
# selected categorical key variables: gender, occupation/education and age

selectedKeyVars = c("sex_","childage", "b_d4") ##!!! Replace with candidate categorical demo vars
selectedHouseholdID = c('hhid') ##!!! Replace with household id
# creating the sdcMicro object with the assigned variables
sdcInitial <- createSdcObj(dat = mydata, keyVars = selectedKeyVars, 
                           hhId = selectedHouseholdID)
sdcInitial

#' #Open-ends: review responses for any sensitive information, redact as necessary
# !!! No Open-Ends

#' #GPS data: Displace
# !!! No GPS data

#' #Save processed data in Stata and SPSS format
#' Adds "_PU" (Public Use) to the end of the name 

haven::write_dta(mydata, paste0(filename, "_PU.dta"))
haven::write_sav(mydata, paste0(filename, "_PU.sav"))

# Add report title dynamically
title_var <- paste0("DOL-ILAB SDC - ", filename)
#'---
#'  title: `r title_var`
#'---
