#' ---
#' author: "Pablo Diego-Rosell, PhD"
#' email: "pablo_diego_rosell@yahoo.com"
#' output:
#'    html_document:
#'      toc: true
#' theme: united
#' ---

rm(list=ls(all=t))

#' #Setup filenames, data, functions and create dictionary for dataset review

filename <- "Malawi_HHHead_Public Use" # !!!Update filename
functions_vers <-  "functions_1.7.R" # !!!Update helper functions file
source (functions_vers)
#'
#' Visually inspect variables in "dictionary.csv" and flag for risk, using the following flags: 
# Direct PII: Respondent Names, Addresses, Identification Numbers, Phone Numbers
# Direct PII-team: Interviewer Names, other field team names 
# Indirect PII-ordinal: Date of birth, Age, income, education, household composition. 
# Indirect PII-categorical: Gender, education, ethnicity, nationality,
# occupation, employer, head of household, marital status
# GPS: Longitude, Latitude
# Small Location: Location (<100,000) 
# Large Location (>100,000)
# Weight: weightVar
# Household ID:  hhId, 
# Open-ends: Review responses for any sensitive information, redact as necessary 

#' #Direct PII: variables to be removed

# !!!Include any Direct PII variables
dropvars <- c("b_edunames_",
              "b_empname_",
              "b_else_members_",
              "b_tob_members_",
              "b_rel_names_") 
mydata <- mydata[!names(mydata) %in% dropvars]

#' #Direct PII-team: Encode field team names
#' !!!No Direct PII-Team 

#' #Small locations: Encode locations  with pop <100,000 using random large numbers
#'  !!!Include relevant variables, but check their population size first to confirm they are <100,000

locvars <- c("community",
             "comm",
             "b_treat",
             "b_comm",
             "e_community",
             "e_comm",
             "b_ta",
             "e_ta") 
mydata <- encode_location (variables= locvars, missing=999999)


#' #Indirect PII - Ordinal: Global recode or Top/bottom coding for extreme values
# Focus on variables with a "Lowest Freq" in dictionary of 30 or less. 

mydata <- top_recode ("num_people", break_point=10, missing=c(888, 999999)) # Topcode cases with 10 or more household members. 
mydata <- top_recode ("b_hhcount", break_point=10, missing=c(888, 999999)) # Topcode cases with 10 or more household members.
mydata <- top_recode ("e_hhcount", break_point=10, missing=c(888, 999999)) # Topcode cases with 10 or more household members.
mydata <- top_recode ("e_num_people", break_point=10, missing=c(888, 999999)) # Topcode cases with 10 or more household members.

# Top code number of loans taken in the last year

mydata <- top_recode ("e_loannum", break_point=10, missing=c(88)) # Topcode cases with 10 or more loans taken. 
mydata <- top_recode ("loannum", break_point=10, missing=c(88)) # Topcode cases with 10 or more loans taken. 
mydata <- top_recode ("b_loannum", break_point=10, missing=88) # Topcode cases with 10 or more loans taken. 
mydata <- top_recode ("b_tobearn_", break_point=5000, missing=c(66666, 88888)) # Topcode cases with 10 or more loans taken. 
mydata <- top_recode ("b_adultearn_", break_point=50000, missing=c(66666, 88888)) # Topcode cases with 10 or more loans taken. 

# Top code high income to the 99.5 percentile

mydata <- top_recode (variable="save1", break_point=70000, missing=88888)

percentile_99.5 <- percentile_checker("saveall", missing=c(88888))
mydata <- top_recode (variable="saveall", break_point=percentile_99.5, missing=88888)

percentile_99.5 <- percentile_checker("loanval", missing=c(88888,888888))
mydata <- top_recode (variable="loanval", break_point=percentile_99.5, missing=c(88888,888888))

percentile_99.5 <- percentile_checker("b_totalsave", missing=c(88888,888888))
mydata <- top_recode (variable="b_totalsave", break_point=percentile_99.5, missing=c(88888,888888))

mydata <- top_recode (variable="b_loanval", break_point=10000000, missing=c(88888,888888, 88888888))

percentile_99.5 <- percentile_checker("e_save1", missing=c(88888))
mydata <- top_recode (variable="e_save1", break_point=percentile_99.5, missing=88888)

percentile_99.5 <- percentile_checker("e_saveall", missing=c(88888))
mydata <- top_recode (variable="e_saveall", break_point=percentile_99.5, missing=88888)

percentile_99.5 <- percentile_checker("e_loanval", missing=c(88888,888888))
mydata <- top_recode (variable="e_loanval", break_point=percentile_99.5, missing=c(88888,888888))

percentile_99.5 <- percentile_checker("b_sav", missing=c(88888,888888888))
mydata <- top_recode (variable="b_sav", break_point=percentile_99.5, missing=c(88888,888888888))

percentile_99.5 <- percentile_checker("b_earn_a_", missing=c(8888,66666,88888))
mydata <- top_recode (variable="b_earn_a_", break_point=percentile_99.5, missing=c(8888,66666,88888))

percentile_99.5 <- percentile_checker("b_earn_b_", missing=c(8888,66666,88888))
mydata <- top_recode (variable="b_earn_b_", break_point=percentile_99.5, missing=c(8888,66666,88888))

percentile_99.5 <- percentile_checker("b_earn_c_", missing=c(6666,8888,66666,88888,666666,888888))
mydata <- top_recode (variable="b_earn_c_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888))

percentile_99.5 <- percentile_checker("b_earn_d_", missing=c(6666,8888,66666,88888,666666,888888))
mydata <- top_recode (variable="b_earn_d_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888))

percentile_99.5 <- percentile_checker("b_earn_e_", missing=c(6666,8888,66666,88888,666666,888888))
mydata <- top_recode (variable="b_earn_e_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888))

percentile_99.5 <- percentile_checker("b_earn_f_", missing=c(6666,8888,66666,88888,666666,888888))
mydata <- top_recode (variable="b_earn_f_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888))

percentile_99.5 <- percentile_checker("b_earn_h_", missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))
mydata <- top_recode (variable="b_earn_h_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))

percentile_99.5 <- percentile_checker("b_earn_i_", missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))
mydata <- top_recode (variable="b_earn_i_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))

percentile_99.5 <- percentile_checker("b_earn_j_", missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))
mydata <- top_recode (variable="b_earn_j_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))

percentile_99.5 <- percentile_checker("b_earn_l_", missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))
mydata <- top_recode (variable="b_earn_l_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))

percentile_99.5 <- percentile_checker("b_earn_o_", missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))
mydata <- top_recode (variable="b_earn_o_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))

percentile_99.5 <- percentile_checker("b_earn_p_", missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))
mydata <- top_recode (variable="b_earn_p_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))

percentile_99.5 <- percentile_checker("b_earn_q_", missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))
mydata <- top_recode (variable="b_earn_q_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))

percentile_99.5 <- percentile_checker("b_earn_r_", missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))
mydata <- top_recode (variable="b_earn_r_", break_point=percentile_99.5, missing=c(6666,8888,66666,88888,666666,888888,666666666,888888888))

mydata$e_hhroster_count<- as.numeric(mydata$e_hhroster_count)
hist(mydata$e_hhroster_count)
mydata <- top_recode (variable="e_hhroster_count", break_point=10, missing=NA)

mydata$e_eligiblechild_<- as.numeric(mydata$e_eligiblechild_)
hist(mydata$e_eligiblechild_)
mydata2 <- top_recode (variable="e_eligiblechild_", break_point=10, missing=NA)

#' #Indirect PII - CategOrical: Recode, encode, or Top/bottom coding for extreme values
# !!!Include relevant variables in list below (Indirect PII - Categorical, and Ordinal if not processed yet)

indirect_PII <- c("schdays_",
                  "ownfarm_",
                  "homehrs_",
                  "hrsun",
                  "hrmon",
                  "hrtues",
                  "hrwed",
                  "hrthur",
                  "hrfri",
                  "hrsat",
                  "bhrsun",
                  "bhrmon",
                  "bhrtues",
                  "bhrwed",
                  "bhrthur",
                  "bhrfri",
                  "bhrsat",
                  "chrsun",
                  "chrmon",
                  "chrtues",
                  "chrwed",
                  "chrthur",
                  "chrfri",
                  "chrsat",
                  "dhrsun",
                  "dhrmon",
                  "dhrtues",
                  "dhrwed",
                  "dhrthur",
                  "dhrfri",
                  "dhrsat",
                  "ehrsun",
                  "ehrmon",
                  "ehrtues",
                  "ehrwed",
                  "ehrthur",
                  "ehrfri",
                  "ehrsat",
                  "fhrsun",
                  "fhrmon",
                  "fhrtues",
                  "fhrwed",
                  "fhrthur",
                  "fhrfri",
                  "fhrsat",
                  "ghrsun",
                  "ghrmon",
                  "ghrtues",
                  "ghrwed",
                  "ghrthur",
                  "ghrfri",
                  "ghrsat",
                  "hhrsun",
                  "hhrmon",
                  "hhrtues",
                  "hhrwed",
                  "hhrthur",
                  "hhrfri",
                  "hhrsat",
                  "ihrsun",
                  "ihrmon",
                  "ihrtues",
                  "ihrwed",
                  "ihrthur",
                  "ihrfri",
                  "ihrsat",
                  "jhrsun",
                  "jhrmon",
                  "jhrtues",
                  "jhrwed",
                  "jhrthur",
                  "jhrfri",
                  "jhrsat",
                  "khrsun",
                  "khrmon",
                  "khrtues",
                  "khrwed",
                  "khrthur",
                  "khrfri",
                  "khrsat",
                  "lhrsun",
                  "lhrmon",
                  "lhrtues",
                  "lhrwed",
                  "lhrthur",
                  "lhrfri",
                  "lhrsat",
                  "mhrsun",
                  "mhrmon",
                  "mhrtues",
                  "mhrwed",
                  "mhrthur",
                  "mhrfri",
                  "mhrsat",
                  "nhrsun",
                  "nhrmon",
                  "nhrtues",
                  "nhrwed",
                  "nhrthur",
                  "nhrfri",
                  "nhrsat",
                  "ohrsun",
                  "ohrmon",
                  "ohrtues",
                  "ohrwed",
                  "ohrthur",
                  "ohrfri",
                  "ohrsat",
                  "phrsun",
                  "phrmon",
                  "phrtues",
                  "phrwed",
                  "phrthur",
                  "phrfri",
                  "phrsat",
                  "qhrsun",
                  "qhrmon",
                  "qhrtues",
                  "qhrwed",
                  "qhrthur",
                  "qhrfri",
                  "qhrsat",
                  "rhrsun",
                  "rhrmon",
                  "rhrtues",
                  "rhrwed",
                  "rhrthur",
                  "rhrfri",
                  "rhrsat",
                  "thrsun",
                  "thrmon",
                  "thrtues",
                  "thrwed",
                  "thrthur",
                  "thrfri",
                  "thrsat",
                  "othhaz_a_",
                  "exp_e_",
                  "religion_",
                  "yardwork",
                  "bird",
                  "firewood",
                  "alcohol",
                  "brick",
                  "hrsworked",
                  "latehrs",
                  "b_preprimary",
                  "b_yardwork",
                  "b_bird",
                  "b_bar",
                  "b_alcohol",
                  "b_hrsun",
                  "b_hrmon",
                  "b_hrtue",
                  "b_hrwed",
                  "b_hrthur",
                  "b_hrfri",
                  "b_hrsat",
                  "b_hrsworked",
                  "b_sex_",
                  "b_currentenroll",
                  "b_schdays_",
                  "b_sex_hh",
                  "e_preprimary",
                  "e_yardwork",
                  "e_bird",
                  "e_firewood",
                  "e_alcohol",
                  "e_brick",
                  "e_hrsworked",
                  "e_latehrs",
                  "e_schdays_",
                  "b_nenroll_",
                  "b_grade_",
                  "b_scheme_",
                  "b_schmtyp_",
                  "b_schmsrc_",
                  "b_emp_b_",
                  "b_emp_e_",
                  "b_emp_g_",
                  "b_emp_h_",
                  "b_emp_i_",
                  "b_emp_j_",
                  "b_emp_m_masked",
                  "b_emp_n_",
                  "b_emp_o_",
                  "b_emp_p_",
                  "b_emp_q_",
                  "b_emp_r_",
                  "b_ownfarm_",
                  "b_tobowntime_",
                  "b_tobactivity_a_",
                  "b_tobactivity_b_",
                  "b_tobactivity_c_",
                  "b_tobactivity_d_",
                  "b_tobactivity_e_",
                  "b_tobactivity_i_",
                  "b_homehrs_",
                  "b_tobhrsown_a_",
                  "b_tobhrsown_b_",
                  "b_expo_",
                  "b_time_",
                  "b_adulttob_",
                  "b_reli_",
                  "b_savings",
                  "b_savingsall",
                  "b_vslawho",
                  "b_vslause",
                  "b_loanwhere",
                  "b_loanuse",
                  "b_fs1",
                  "b_water",
                  "b_inc1a_wsh_masked",
                  "b_inc1a_wsh_masked",
                  "b_inc1a_pmp_masked",
                  "b_inc2",
                  "b_inc2_number",
                  "b_inc3a",
                  "b_els_a_",
                  "b_els_b_",
                  "b_els_c_",
                  "b_els_d_",
                  "b_els_e_",
                  "b_els_f_",
                  "b_els_g_",
                  "b_els_h_",
                  "b_els_i_",
                  "b_els_j_",
                  "b_els_k_",
                  "b_els_l_",
                  "b_els_m_",
                  "b_els_n_",
                  "b_els_o_",
                  "b_els_p_",
                  "b_els_q_",
                  "b_els_r_",
                  "b_time_hrs_sun_a_",
                  "b_time_hrs_sun_b_",
                  "b_time_hrs_sun_c_",
                  "b_time_hrs_sun_d_",
                  "b_time_hrs_sun_e_",
                  "b_time_hrs_sun_f_",
                  "b_time_hrs_sun_g_",
                  "b_time_hrs_sun_h_",
                  "b_time_hrs_sun_i_",
                  "b_time_hrs_sun_j_",
                  "b_time_hrs_sun_k_",
                  "b_time_hrs_sun_l_",
                  "b_time_hrs_sun_m_",
                  "b_time_hrs_sun_n_",
                  "b_time_hrs_sun_o_",
                  "b_time_hrs_sun_p_",
                  "b_time_hrs_sun_q_",
                  "b_time_hrs_sun_r_",
                  "b_time_min_sun_a_",
                  "b_time_min_sun_b_",
                  "b_time_min_sun_c_",
                  "b_time_min_sun_d_",
                  "b_time_min_sun_e_",
                  "b_time_min_sun_f_",
                  "b_time_min_sun_g_",
                  "b_time_min_sun_h_",
                  "b_time_min_sun_i_",
                  "b_time_min_sun_j_",
                  "b_time_min_sun_k_",
                  "b_time_min_sun_l_",
                  "b_time_min_sun_m_",
                  "b_time_min_sun_n_",
                  "b_time_min_sun_o_",
                  "b_time_min_sun_p_",
                  "b_time_min_sun_q_",
                  "b_time_min_sun_r_",
                  "b_time_hrs_mon_a_",
                  "b_time_hrs_mon_b_",
                  "b_time_hrs_mon_c_",
                  "b_time_hrs_mon_d_",
                  "b_time_hrs_mon_e_",
                  "b_time_hrs_mon_f_",
                  "b_time_hrs_mon_g_",
                  "b_time_hrs_mon_h_",
                  "b_time_hrs_mon_i_",
                  "b_time_hrs_mon_j_",
                  "b_time_hrs_mon_k_",
                  "b_time_hrs_mon_l_",
                  "b_time_hrs_mon_m_",
                  "b_time_hrs_mon_n_",
                  "b_time_hrs_mon_o_",
                  "b_time_hrs_mon_p_",
                  "b_time_hrs_mon_q_",
                  "b_time_hrs_mon_r_",
                  "b_time_min_mon_a_",
                  "b_time_min_mon_b_",
                  "b_time_min_mon_c_",
                  "b_time_min_mon_d_",
                  "b_time_min_mon_e_",
                  "b_time_min_mon_f_",
                  "b_time_min_mon_g_",
                  "b_time_min_mon_h_",
                  "b_time_min_mon_i_",
                  "b_time_min_mon_j_",
                  "b_time_min_mon_k_",
                  "b_time_min_mon_l_",
                  "b_time_min_mon_m_",
                  "b_time_min_mon_n_",
                  "b_time_min_mon_o_",
                  "b_time_min_mon_p_",
                  "b_time_min_mon_q_",
                  "b_time_min_mon_r_",
                  "b_time_hrs_tue_a_",
                  "b_time_hrs_tue_b_",
                  "b_time_hrs_tue_c_",
                  "b_time_hrs_tue_d_",
                  "b_time_hrs_tue_e_",
                  "b_time_hrs_tue_f_",
                  "b_time_hrs_tue_g_",
                  "b_time_hrs_tue_h_",
                  "b_time_hrs_tue_i_",
                  "b_time_hrs_tue_j_",
                  "b_time_hrs_tue_k_",
                  "b_time_hrs_tue_l_",
                  "b_time_hrs_tue_m_",
                  "b_time_hrs_tue_n_",
                  "b_time_hrs_tue_o_",
                  "b_time_hrs_tue_p_",
                  "b_time_hrs_tue_q_",
                  "b_time_hrs_tue_r_",
                  "b_time_min_tue_a_",
                  "b_time_min_tue_b_",
                  "b_time_min_tue_c_",
                  "b_time_min_tue_d_",
                  "b_time_min_tue_e_",
                  "b_time_min_tue_f_",
                  "b_time_min_tue_g_",
                  "b_time_min_tue_h_",
                  "b_time_min_tue_i_",
                  "b_time_min_tue_j_",
                  "b_time_min_tue_k_",
                  "b_time_min_tue_l_",
                  "b_time_min_tue_m_",
                  "b_time_min_tue_n_",
                  "b_time_min_tue_p_",
                  "b_time_min_tue_q_",
                  "b_time_min_tue_r_",
                  "b_time_hrs_wed_a_",
                  "b_time_hrs_wed_b_",
                  "b_time_hrs_wed_c_",
                  "b_time_hrs_wed_d_",
                  "b_time_hrs_wed_e_",
                  "b_time_hrs_wed_f_",
                  "b_time_hrs_wed_g_",
                  "b_time_hrs_wed_h_",
                  "b_time_hrs_wed_i_",
                  "b_time_hrs_wed_j_",
                  "b_time_hrs_wed_k_",
                  "b_time_hrs_wed_l_",
                  "b_time_hrs_wed_m_",
                  "b_time_hrs_wed_n_",
                  "b_time_hrs_wed_o_",
                  "b_time_hrs_wed_p_",
                  "b_time_hrs_wed_q_",
                  "b_time_hrs_wed_r_",
                  "b_time_min_wed_a_",
                  "b_time_min_wed_b_",
                  "b_time_min_wed_c_",
                  "b_time_min_wed_d_",
                  "b_time_min_wed_e_",
                  "b_time_min_wed_f_",
                  "b_time_min_wed_g_",
                  "b_time_min_wed_h_",
                  "b_time_min_wed_i_",
                  "b_time_min_wed_j_",
                  "b_time_min_wed_k_",
                  "b_time_min_wed_l_",
                  "b_time_min_wed_m_",
                  "b_time_min_wed_n_",
                  "b_time_min_wed_o_",
                  "b_time_min_wed_p_",
                  "b_time_min_wed_q_",
                  "b_time_min_wed_r_",
                  "b_time_hrs_thu_a_",
                  "b_time_hrs_thu_b_",
                  "b_time_hrs_thu_c_",
                  "b_time_hrs_thu_d_",
                  "b_time_hrs_thu_e_",
                  "b_time_hrs_thu_f_",
                  "b_time_hrs_thu_g_",
                  "b_time_hrs_thu_h_",
                  "b_time_hrs_thu_i_",
                  "b_time_hrs_thu_j_",
                  "b_time_hrs_thu_k_",
                  "b_time_hrs_thu_l_",
                  "b_time_hrs_thu_m_",
                  "b_time_hrs_thu_n_",
                  "b_time_hrs_thu_o_",
                  "b_time_hrs_thu_p_",
                  "b_time_hrs_thu_q_",
                  "b_time_hrs_thu_r_",
                  "b_time_min_thu_a_",
                  "b_time_min_thu_b_",
                  "b_time_min_thu_c_",
                  "b_time_min_thu_d_",
                  "b_time_min_thu_e_",
                  "b_time_min_thu_f_",
                  "b_time_min_thu_g_",
                  "b_time_min_thu_h_",
                  "b_time_min_thu_i_",
                  "b_time_min_thu_j_",
                  "b_time_min_thu_k_",
                  "b_time_min_thu_l_",
                  "b_time_min_thu_m_",
                  "b_time_min_thu_n_",
                  "b_time_min_thu_p_",
                  "b_time_min_thu_q_",
                  "b_time_min_thu_r_",
                  "b_time_hrs_fri_a_",
                  "b_time_hrs_fri_b_",
                  "b_time_hrs_fri_c_",
                  "b_time_hrs_fri_d_",
                  "b_time_hrs_fri_e_",
                  "b_time_hrs_fri_f_",
                  "b_time_hrs_fri_g_",
                  "b_time_hrs_fri_h_",
                  "b_time_hrs_fri_i_",
                  "b_time_hrs_fri_j_",
                  "b_time_hrs_fri_k_",
                  "b_time_hrs_fri_l_",
                  "b_time_hrs_fri_m_",
                  "b_time_hrs_fri_n_",
                  "b_time_hrs_fri_o_",
                  "b_time_hrs_fri_p_",
                  "b_time_hrs_fri_q_",
                  "b_time_hrs_fri_r_",
                  "b_time_min_fri_a_",
                  "b_time_min_fri_b_",
                  "b_time_min_fri_c_",
                  "b_time_min_fri_d_",
                  "b_time_min_fri_e_",
                  "b_time_min_fri_f_",
                  "b_time_min_fri_g_",
                  "b_time_min_fri_h_",
                  "b_time_min_fri_i_",
                  "b_time_min_fri_j_",
                  "b_time_min_fri_k_",
                  "b_time_min_fri_l_",
                  "b_time_min_fri_m_",
                  "b_time_min_fri_n_",
                  "b_time_min_fri_o_",
                  "b_time_min_fri_p_",
                  "b_time_min_fri_q_",
                  "b_time_min_fri_r_",
                  "b_time_hrs_sat_a_",
                  "b_time_hrs_sat_b_",
                  "b_time_hrs_sat_c_",
                  "b_time_hrs_sat_d_",
                  "b_time_hrs_sat_e_",
                  "b_time_hrs_sat_f_",
                  "b_time_hrs_sat_g_",
                  "b_time_hrs_sat_h_",
                  "b_time_hrs_sat_i_",
                  "b_time_hrs_sat_j_",
                  "b_time_hrs_sat_k_",
                  "b_time_hrs_sat_l_",
                  "b_time_hrs_sat_m_",
                  "b_time_hrs_sat_n_",
                  "b_time_hrs_sat_o_",
                  "b_time_hrs_sat_p_",
                  "b_time_hrs_sat_q_",
                  "b_time_hrs_sat_r_",
                  "b_time_min_sat_a_",
                  "b_time_min_sat_b_",
                  "b_time_min_sat_c_",
                  "b_time_min_sat_d_",
                  "b_time_min_sat_e_",
                  "b_time_min_sat_f_",
                  "b_time_min_sat_g_",
                  "b_time_min_sat_h_",
                  "b_time_min_sat_i_",
                  "b_time_min_sat_j_",
                  "b_time_min_sat_k_",
                  "b_time_min_sat_l_",
                  "b_time_min_sat_m_",
                  "b_time_min_sat_n_",
                  "b_time_min_sat_o_",
                  "b_time_min_sat_p_",
                  "b_time_min_sat_q_",
                  "b_time_min_sat_r_",
                  "b_earn_g_",
                  "b_earn_k_",
                  "b_earn_m_",
                  "b_earn_n_",
                  "e_live_",
                  "e_nenroll_",
                  "e_grade_",
                  "e_scheme_",
                  "e_schmtyp_",
                  "e_schmtyp_a_",
                  "e_schmtyp_g_",
                  "e_schmtyp_h_",
                  "e_schmsrc_",
                  "e_schmsrc_a_",
                  "e_schmsrc_c_",
                  "e_schmsrc_f_",
                  "e_schmsrc_g_",
                  "e_schmsrc_h_",
                  "e_emp_a_",
                  "e_emp_d_",
                  "e_emp_e_",
                  "e_emp_f_",
                  "e_emp_g_",
                  "e_emp_h_",
                  "e_emp_i_",
                  "e_emp_j_",
                  "e_emp_l_",
                  "e_emp_m_",
                  "e_emp_n_",
                  "e_emp_o_masked",
                  "e_emp_p_",
                  "e_emp_q_",
                  "e_emp_r_",
                  "e_ownfarm_",
                  "e_tobowntime_",
                  "e_tobactivity_b_",
                  "e_tobactivity_c_",
                  "e_tobactivity_f_",
                  "e_tobactivity_j_",
                  "e_homehrs_",
                  "e_hrsun",
                  "e_hrmon",
                  "e_hrtues",
                  "e_hrwed",
                  "e_hrthur",
                  "e_hrfri",
                  "e_hrsat",
                  "e_bhrsun",
                  "e_bhrmon",
                  "e_bhrtues",
                  "e_bhrwed",
                  "e_bhrthur",
                  "e_bhrfri",
                  "e_bhrsat",
                  "e_chrsun",
                  "e_chrmon",
                  "e_chrtues",
                  "e_chrwed",
                  "e_chrthur",
                  "e_chrfri",
                  "e_chrsat",
                  "e_dhrsun",
                  "e_dhrmon",
                  "e_dhrtues",
                  "e_dhrwed",
                  "e_dhrthur",
                  "e_dhrfri",
                  "e_dhrsat",
                  "e_ehrsun",
                  "e_ehrmon",
                  "e_ehrtues",
                  "e_ehrwed",
                  "e_ehrthur",
                  "e_ehrfri",
                  "e_ehrsat",
                  "e_fhrsun",
                  "e_fhrmon",
                  "e_fhrtues",
                  "e_fhrwed",
                  "e_fhrthur",
                  "e_fhrfri",
                  "e_fhrsat",
                  "e_ghrsun",
                  "e_ghrmon",
                  "e_ghrtues",
                  "e_ghrwed",
                  "e_ghrthur",
                  "e_ghrfri",
                  "e_ghrsat",
                  "e_hhrsun",
                  "e_hhrmon",
                  "e_hhrtues",
                  "e_hhrwed",
                  "e_hhrthur",
                  "e_hhrfri",
                  "e_hhrsat",
                  "e_ihrsun",
                  "e_ihrmon",
                  "e_ihrtues",
                  "e_ihrwed",
                  "e_ihrthur",
                  "e_ihrfri",
                  "e_ihrsat",
                  "e_jhrsun",
                  "e_jhrmon",
                  "e_jhrtues",
                  "e_jhrwed",
                  "e_jhrthur",
                  "e_jhrfri",
                  "e_jhrsat",
                  "e_khrsun",
                  "e_khrmon",
                  "e_khrtues",
                  "e_khrwed",
                  "e_khrthur",
                  "e_khrfri",
                  "e_khrsat",
                  "e_lhrsun",
                  "e_lhrmon",
                  "e_lhrtues",
                  "e_lhrwed",
                  "e_lhrthur",
                  "e_lhrfri",
                  "e_lhrsat",
                  "e_mhrsun",
                  "e_mhrmon",
                  "e_mhrtues",
                  "e_mhrwed",
                  "e_mhrthur",
                  "e_mhrfri",
                  "e_mhrsat",
                  "e_nhrsun",
                  "e_nhrmon",
                  "e_nhrtues",
                  "e_nhrwed",
                  "e_nhrthur",
                  "e_nhrfri",
                  "e_nhrsat",
                  "e_ohrsun",
                  "e_ohrmon",
                  "e_ohrtues",
                  "e_ohrwed",
                  "e_ohrthur",
                  "e_ohrfri",
                  "e_ohrsat",
                  "e_phrsun",
                  "e_phrmon",
                  "e_phrtues",
                  "e_phrwed",
                  "e_phrthur",
                  "e_phrfri",
                  "e_phrsat",
                  "e_qhrsun",
                  "e_qhrmon",
                  "e_qhrtues",
                  "e_qhrwed",
                  "e_qhrthur",
                  "e_qhrfri",
                  "e_qhrsat",
                  "e_rhrsun",
                  "e_rhrmon",
                  "e_rhrtues",
                  "e_rhrwed",
                  "e_rhrthur",
                  "e_rhrfri",
                  "e_rhrsat",
                  "e_thrsun",
                  "e_thrmon",
                  "e_thrtues",
                  "e_thrwed",
                  "e_thrthur",
                  "e_thrfri",
                  "e_thrsat",
                  "e_earn_a__masked",
                  "e_earn_b__masked",
                  "e_earn_c__masked",
                  "e_earn_d__masked",
                  "e_earn_e__masked",
                  "e_earn_f__masked",
                  "e_earn_g__masked",
                  "e_earn_h__masked",
                  "e_earn_i__masked",
                  "e_earn_j__masked",
                  "e_earn_l__masked",
                  "e_earn_m__masked",
                  "e_earn_n__masked",
                  "e_earn_p__masked",
                  "e_earn_q__masked",
                  "e_earn_r__masked",
                  "e_tobseas_",
                  "e_tobhrsown_a_",
                  "e_tobhrsown_b_",
                  "e_tobearn__masked",
                  "e_othhaz_",
                  "e_othhaz_a_",
                  "e_exp_",
                  "e_exp_e_",
                  "e_timeofday_",
                  "e_adulttob_",
                  "e_religion_",
                  "e_tribe_",
                  "e_savings",
                  "e_savingsall",
                  "e_vslawho",
                  "e_vslawho_e",
                  "e_vslawho_g",
                  "e_vslawho_h",
                  "e_vslawho_i",
                  "e_vslawho_j",
                  "e_vslalen_num",
                  "e_vslapay",
                  "e_vslause",
                  "e_vslause_g",
                  "e_vslause_i",
                  "e_vslause_j",
                  "e_loanwhere",
                  "e_loanuse",
                  "e_loanuse_g",
                  "e_inc1a_9_masked",
                  "e_inc1a_11_masked",
                  "e_inca_b",
                  "e_inc3a",
                  "b_tribe_")

capture_tables (indirect_PII)


# Recode races or ethnicity to reduce risk of re-identification

haven_table("e_tribe_")
#val_labels(mydata$b_tribe_)
mydata$b_tribe_ <- recode(mydata$b_tribe_, 
                      `1`=1L, 
                      `2`=77L, 
                      `3`=3L, 
                      `4`=4L, 
                      `5`=5L, 
                      `6`=77L, 
                      `7`=7L, 
                      `8`=77L, 
                      `9`=77L,
                      `10`=10L, 
                      `11`=77L, 
                      `12`=77L, 
                      `13`=13L, 
                      `77`=77L, 
                      `88`=88L)

mydata$e_tribe_ <- recode(mydata$e_tribe_, 
                          `1`=1L, 
                          `2`=77L, 
                          `3`=3L, 
                          `4`=4L, 
                          `5`=5L, 
                          `6`=77L, 
                          `7`=7L, 
                          `8`=77L, 
                          `9`=77L,
                          `10`=10L, 
                          `11`=77L, 
                          `12`=77L, 
                          `13`=13L, 
                          `77`=77L, 
                          `88`=88L)

# Recode those with very specific values. 

#' #Matching and crosstabulations: Run automated PII check 

# Based on dictionary inspection, select variables for creating sdcMicro object
# See: https://sdcpractice.readthedocs.io/en/latest/anon_methods.html
# All variable names should correspond to the names in the data file
# selected categorical key variables: gender, occupation/education and age

mydata$sex_summary <- cbind(mydata$b_sex_, mydata$e_sex_)
mydata$age_summary <- cbind(mydata$b_age_masked, mydata$e_age_masked)

educ_vars<- c("b_chprepri", "b_chpri", "b_chuppri", "b_chsec", "b_chhighersec")
mydata$edu_sum1 <- names(mydata[educ_vars])[max.col(mydata[educ_vars])]

educ_vars<- c("e_chprepri", "e_chpri", "e_chuppri", "e_chsec", "e_chhighersec")
mydata$edu_sum2 <- names(mydata[educ_vars])[max.col(mydata[educ_vars])]
mydata$edu_summary <- paste(mydata$edu_sum1, mydata$edu_sum2)

selectedKeyVars = c("sex_summary", "age_summary", "edu_summary")
selectedHouseholdID = c('hhid')
sdcInitial <- createSdcObj(dat = mydata, keyVars = selectedKeyVars, 
                           hhId = selectedHouseholdID)
sdcInitial

dropvars <- c("sex_summary",
              "age_summary",
              "edu_summary",
              "edu_sum1",
              "edu_sum2") 
mydata <- mydata[!names(mydata) %in% dropvars]

#' #Open-ends: review responses for any sensitive information, redact as necessary
#' 
# !!! Identify open-end variables here: 
open_ends <- c("b_live_sp_",
               "b_othhaz_",
               "b_vsla_desc",
               "b_loanaccess_get",
               "b_klabwhy",
               "b_kidlaw_d",
               "e_loanaccess_where",
               "e_klabwhy",
               "e_kidlaw_d",
               "e_kidlaw_e",
               "e_type")

report_open (list_open_ends = open_ends)

# Review "verbatims.csv". Identify variables to be deleted or redacted and their row number 

# Redrafted information in Local Language
mydata$b_vsla_desc[19578] <- "[Local Language]"
mydata$b_vsla_desc[19912] <- "[Local Language]"
mydata$b_vsla_desc[21634] <- "[Local Language]"
mydata$b_vsla_desc[24756] <- "[Local Language]"
mydata$b_vsla_desc[26740] <- "[Local Language]"
mydata$b_vsla_desc[27560] <- "[Local Language]"
mydata$b_vsla_desc[29800] <- "[Local Language]"
mydata$b_vsla_desc[29820] <- "[Local Language]"
mydata$b_vsla_desc[29823] <- "[Local Language]"
mydata$b_vsla_desc[30504] <- "[Local Language]"
mydata$b_vsla_desc[30975] <- "[Local Language]"
mydata$b_vsla_desc[31626] <- "[Local Language]"
mydata$b_vsla_desc[33112] <- "[Local Language]"
mydata$b_vsla_desc[34433] <- "[Local Language]"
mydata$b_vsla_desc[35943] <- "[Local Language]"
mydata$b_vsla_desc[35949] <- "[Local Language]"

#' #GPS data: Displace
# Setup map
# !!!No GPS

#' #Save processed data in Stata and SPSS format
#' Adds "_PU" (Public Use) to the end of the name 

haven::write_dta(mydata, paste0(filename, "_PU.dta"))
haven::write_sav(mydata, paste0(filename, "_PU.sav"))

# Add report title dynamically
title_var <- paste0("DOL-ILAB SDC - ", filename)
#'---
#'  title: `r title_var`
#'---
